gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: -C skeletions


From: gnunet
Subject: [taler-exchange] branch master updated: -C skeletions
Date: Fri, 30 Dec 2022 14:24:51 +0100

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new c002f458 -C skeletions
c002f458 is described below

commit c002f458ce3d532b633d345427e713a81239e108
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Fri Dec 30 14:24:48 2022 +0100

    -C skeletions
---
 src/exchangedb/pg_insert_aml_decision.c           | 16 ++++++++++++++++
 src/exchangedb/pg_insert_aml_officer.c            | 15 +++++++++++++++
 src/exchangedb/pg_insert_kyc_attributes.c         | 17 +++++++++++++++++
 src/exchangedb/pg_lookup_aml_officer.c            | 14 ++++++++++++++
 src/exchangedb/pg_select_aml_history.c            | 11 +++++++++++
 src/exchangedb/pg_select_aml_process.c            | 14 ++++++++++++++
 src/exchangedb/pg_select_kyc_attributes.c         | 12 ++++++++++++
 src/exchangedb/pg_select_similar_kyc_attributes.c | 12 ++++++++++++
 src/exchangedb/pg_select_similar_kyc_attributes.h |  8 ++++----
 src/exchangedb/pg_trigger_aml_process.c           | 11 +++++++++++
 src/exchangedb/pg_update_aml_officer.c            | 15 +++++++++++++++
 src/exchangedb/pg_update_kyc_attributes.c         | 17 +++++++++++++++++
 src/exchangedb/plugin_exchangedb_postgres.c       |  2 --
 13 files changed, 158 insertions(+), 6 deletions(-)

diff --git a/src/exchangedb/pg_insert_aml_decision.c 
b/src/exchangedb/pg_insert_aml_decision.c
index 242bb748..25ad4c56 100644
--- a/src/exchangedb/pg_insert_aml_decision.c
+++ b/src/exchangedb/pg_insert_aml_decision.c
@@ -24,3 +24,19 @@
 #include "taler_pq_lib.h"
 #include "pg_insert_aml_decision.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_insert_aml_decision (
+  void *cls,
+  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_Amount *new_threshold,
+  enum TALER_AmlDecisionState new_status,
+  struct GNUNET_TIME_Absolute decision_time,
+  const char *justification,
+  const struct TALER_AmlOfficerPublicKeyP *decider_pub,
+  const struct TALER_AmlOfficerSignatureP *decider_sig)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_insert_aml_officer.c 
b/src/exchangedb/pg_insert_aml_officer.c
index 73093b75..89b7ffae 100644
--- a/src/exchangedb/pg_insert_aml_officer.c
+++ b/src/exchangedb/pg_insert_aml_officer.c
@@ -24,3 +24,18 @@
 #include "taler_pq_lib.h"
 #include "pg_insert_aml_officer.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_insert_aml_officer (
+  void *cls,
+  const struct TALER_AmlOfficerPublicKeyP *decider_pub,
+  const struct TALER_MasterSignatureP *master_sig,
+  const char *decider_name,
+  bool is_active,
+  bool read_only,
+  struct GNUNET_TIME_Absolute last_change)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_insert_kyc_attributes.c 
b/src/exchangedb/pg_insert_kyc_attributes.c
index 7206fc21..5714e2aa 100644
--- a/src/exchangedb/pg_insert_kyc_attributes.c
+++ b/src/exchangedb/pg_insert_kyc_attributes.c
@@ -24,3 +24,20 @@
 #include "taler_pq_lib.h"
 #include "pg_insert_kyc_attributes.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_insert_kyc_attributes (
+  void *cls,
+  const struct TALER_PaytoHashP *h_payto,
+  const struct GNUNET_ShortHashCode *kyc_prox,
+  const char *provider_section,
+  const char *birthdate,
+  struct GNUNET_TIME_Timestamp collection_time,
+  struct GNUNET_TIME_Timestamp expiration_time,
+  size_t enc_attributes_size,
+  const void *enc_attributes)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_lookup_aml_officer.c 
b/src/exchangedb/pg_lookup_aml_officer.c
index 7304b037..245a870e 100644
--- a/src/exchangedb/pg_lookup_aml_officer.c
+++ b/src/exchangedb/pg_lookup_aml_officer.c
@@ -24,3 +24,17 @@
 #include "taler_pq_lib.h"
 #include "pg_lookup_aml_officer.h"
 #include "pg_helper.h"
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_lookup_aml_officer (
+  void *cls,
+  const struct TALER_AmlOfficerPublicKeyP *decider_pub,
+  struct TALER_MasterSignatureP *master_sig,
+  char **decider_name,
+  bool *is_active,
+  bool *read_only,
+  struct GNUNET_TIME_Absolute *last_change)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_select_aml_history.c 
b/src/exchangedb/pg_select_aml_history.c
index 5cd8b00d..2e310878 100644
--- a/src/exchangedb/pg_select_aml_history.c
+++ b/src/exchangedb/pg_select_aml_history.c
@@ -24,3 +24,14 @@
 #include "taler_pq_lib.h"
 #include "pg_select_aml_history.h"
 #include "pg_helper.h"
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_select_aml_history (
+  void *cls,
+  const struct TALER_PaytoHashP *h_payto,
+  TALER_EXCHANGEDB_AmlHistoryCallback cb,
+  void *cb_cls)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_select_aml_process.c 
b/src/exchangedb/pg_select_aml_process.c
index 985942df..9b5dedb3 100644
--- a/src/exchangedb/pg_select_aml_process.c
+++ b/src/exchangedb/pg_select_aml_process.c
@@ -24,3 +24,17 @@
 #include "taler_pq_lib.h"
 #include "pg_select_aml_process.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_select_aml_process (
+  void *cls,
+  enum TALER_AmlDecisionState decision,
+  uint64_t row_off,
+  bool forward,
+  TALER_EXCHANGEDB_AmlStatusCallback cb,
+  void *cb_cls)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_select_kyc_attributes.c 
b/src/exchangedb/pg_select_kyc_attributes.c
index 4e032839..4832df7e 100644
--- a/src/exchangedb/pg_select_kyc_attributes.c
+++ b/src/exchangedb/pg_select_kyc_attributes.c
@@ -24,3 +24,15 @@
 #include "taler_pq_lib.h"
 #include "pg_select_kyc_attributes.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_select_kyc_attributes (
+  void *cls,
+  const struct TALER_PaytoHashP *h_payto,
+  TALER_EXCHANGEDB_AttributeCallback cb,
+  void *cb_cls)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_select_similar_kyc_attributes.c 
b/src/exchangedb/pg_select_similar_kyc_attributes.c
index 26a957e6..27621837 100644
--- a/src/exchangedb/pg_select_similar_kyc_attributes.c
+++ b/src/exchangedb/pg_select_similar_kyc_attributes.c
@@ -24,3 +24,15 @@
 #include "taler_pq_lib.h"
 #include "pg_select_similar_kyc_attributes.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_select_similar_kyc_attributes (
+  void *cls,
+  const struct GNUNET_ShortHashCode *kyc_prox,
+  TALER_EXCHANGEDB_AttributeCallback cb,
+  void *cb_cls)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_trigger_aml_process.c 
b/src/exchangedb/pg_trigger_aml_process.c
index dd3a0ca7..29ac2de1 100644
--- a/src/exchangedb/pg_trigger_aml_process.c
+++ b/src/exchangedb/pg_trigger_aml_process.c
@@ -24,3 +24,14 @@
 #include "taler_pq_lib.h"
 #include "pg_trigger_aml_process.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_trigger_aml_process (
+  void *cls,
+  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_Amount *threshold_crossed)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_update_aml_officer.c 
b/src/exchangedb/pg_update_aml_officer.c
index 9f4ac5f5..aca58f0c 100644
--- a/src/exchangedb/pg_update_aml_officer.c
+++ b/src/exchangedb/pg_update_aml_officer.c
@@ -24,3 +24,18 @@
 #include "taler_pq_lib.h"
 #include "pg_update_aml_officer.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_update_aml_officer (
+  void *cls,
+  const struct TALER_AmlOfficerPublicKeyP *decider_pub,
+  const struct TALER_MasterSignatureP *master_sig,
+  const char *decider_name,
+  bool is_active,
+  bool read_only,
+  struct GNUNET_TIME_Absolute last_change)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/pg_update_kyc_attributes.c 
b/src/exchangedb/pg_update_kyc_attributes.c
index 1501476e..8f0c6fd3 100644
--- a/src/exchangedb/pg_update_kyc_attributes.c
+++ b/src/exchangedb/pg_update_kyc_attributes.c
@@ -24,3 +24,20 @@
 #include "taler_pq_lib.h"
 #include "pg_update_kyc_attributes.h"
 #include "pg_helper.h"
+
+
+enum GNUNET_DB_QueryStatus
+TEH_PG_update_kyc_attributes (
+  void *cls,
+  const struct TALER_PaytoHashP *h_payto,
+  const struct GNUNET_ShortHashCode *kyc_prox,
+  const char *provider_section,
+  const char *birthdate,
+  struct GNUNET_TIME_Timestamp collection_time,
+  struct GNUNET_TIME_Timestamp expiration_time,
+  size_t enc_attributes_size,
+  const void *enc_attributes)
+{
+  GNUNET_break (0); // FIXME: not implemeted!
+  return GNUNET_DB_STATUS_HARD_ERROR;
+}
diff --git a/src/exchangedb/plugin_exchangedb_postgres.c 
b/src/exchangedb/plugin_exchangedb_postgres.c
index 6724a947..cd5773a0 100644
--- a/src/exchangedb/plugin_exchangedb_postgres.c
+++ b/src/exchangedb/plugin_exchangedb_postgres.c
@@ -751,7 +751,6 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_batch_reserves_in_insert;
   plugin->batch2_reserves_in_insert
     = &TEH_PG_batch2_reserves_in_insert;
-#if 0
   plugin->insert_kyc_attributes
     = &TEH_PG_insert_kyc_attributes;
   plugin->update_kyc_attributes
@@ -774,7 +773,6 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_select_aml_history;
   plugin->insert_aml_decision
     = &TEH_PG_insert_aml_decision;
-#endif
   return plugin;
 }
 

diff --git a/src/exchangedb/pg_select_similar_kyc_attributes.h 
b/src/exchangedb/pg_select_similar_kyc_attributes.h
index b3243371..caa311da 100644
--- a/src/exchangedb/pg_select_similar_kyc_attributes.h
+++ b/src/exchangedb/pg_select_similar_kyc_attributes.h
@@ -27,20 +27,20 @@
 
 
 /**
  * Lookup KYC attribute data for a specific account.
  *
  * @param cls closure
  * @param h_payto account for which the attribute data is stored
+ * @param kyc_prox key for similarity search
  * @param cb callback to invoke on each match
  * @param cb_cls closure for @a cb
  * @return database transaction status
  */
 enum GNUNET_DB_QueryStatus
-TEH_PG_select_kyc_attributes (
+TEH_PG_select_similar_kyc_attributes (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct GNUNET_ShortHashCode *kyc_prox,
   TALER_EXCHANGEDB_AttributeCallback cb,
   void *cb_cls);
 
-
 #endif
@@ -27,20 +27,20 @@
 
 /**
- * Lookup KYC attribute data for a specific account.
+ * Lookup similar KYC attribute data.
  *
  * @param cls closure
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]